@@ -19,22 +19,15 @@
 
 #include "mauikit.h"
 
-#include <QDebug>
-
 #include "appsettings.h"
-
 #include "appview.h"
-#include "tabview.h"
 
 #include "handy.h"
 #include "mauiapp.h"
 #include "mauilist.h"
 #include "mauimodel.h"
-#include "pathlist.h"
-
-#ifdef COMPONENT_ACCOUNTS
-#include "mauiaccounts.h"
-#endif
+#include "notify.h"
+#include "tabview.h"
 
 #ifdef Q_OS_ANDROID
 #include "platforms/android/mauiandroid.h"
@@ -44,14 +37,10 @@
 
 #include "platform.h"
 
-#if defined Q_OS_MACOS
-#include <KF5/KI18n/KLocalizedContext>
-#include <KF5/KI18n/KLocalizedString>
-#else
 #include <KI18n/KLocalizedContext>
 #include <KI18n/KLocalizedString>
-#endif
 
+#include <QDebug>
 #include <QQmlContext>
 
 QUrl MauiKit::componentUrl(const QString &fileName) const
@@ -107,9 +96,6 @@ void MauiKit::registerTypes(const char *uri)
 
     qmlRegisterType(componentUrl(QStringLiteral("FloatingButton.qml")), uri, 1, 0, "FloatingButton");
 
-    qmlRegisterType(componentUrl(QStringLiteral("PathBar.qml")), uri, 1, 0, "PathBar");
-    qmlRegisterType<PathList>(uri, 1, 0, "PathList");
-
     /** Shapes **/
     qmlRegisterType(componentUrl(QStringLiteral("private/shapes/X.qml")), uri, 1, 0, "X");
     qmlRegisterType(componentUrl(QStringLiteral("private/shapes/PlusSign.qml")), uri, 1, 0, "PlusSign");
@@ -135,7 +121,7 @@ void MauiKit::registerTypes(const char *uri)
     qmlRegisterType(componentUrl(QStringLiteral("labs/AlternateListItem.qml")), uri, 1, 2, "AlternateListItem");
     qmlRegisterType(componentUrl(QStringLiteral("labs/Separator.qml")), uri, 1, 2, "Separator");
     qmlRegisterType(componentUrl(QStringLiteral("private/BasicToolButton.qml")), uri, 1, 2, "BasicToolButton");
-    
+
     /** 1.3 **/
     qmlRegisterType(componentUrl(QStringLiteral("labs/GalleryRollItem.qml")), uri, 1, 3, "GalleryRollItem");
     qmlRegisterType(componentUrl(QStringLiteral("labs/CollageItem.qml")), uri, 1, 3, "CollageItem");
@@ -147,16 +133,20 @@ void MauiKit::registerTypes(const char *uri)
     qmlRegisterType(componentUrl(QStringLiteral("labs/FlexListItem.qml")), uri, 1, 3, "FlexListItem");
     qmlRegisterType(componentUrl(QStringLiteral("labs/Chip.qml")), uri, 1, 3, "Chip");
     qmlRegisterType(componentUrl(QStringLiteral("labs/ContextualMenu.qml")), uri, 1, 3, "ContextualMenu");
+    qmlRegisterType(componentUrl(QStringLiteral("labs/ComboBox.qml")), uri, 1, 3, "ComboBox");
     qmlRegisterType(componentUrl(QStringLiteral("labs/TabView.qml")), uri, 1, 3, "TabView");
     qmlRegisterType(componentUrl(QStringLiteral("CloseButton.qml")), uri, 1, 3, "CloseButton");
     qmlRegisterType(componentUrl(QStringLiteral("labs/ColorsRow.qml")), uri, 1, 3, "ColorsRow");
-    
+    qmlRegisterType(componentUrl(QStringLiteral("SplitView.qml")), uri, 1, 3, "SplitView");
+    qmlRegisterType(componentUrl(QStringLiteral("SplitViewItem.qml")), uri, 1, 3, "SplitViewItem");
+    qmlRegisterType(componentUrl(QStringLiteral("ProgressIndicator.qml")), uri, 1, 3, "ProgressIndicator");
+
     /// NON UI CONTROLS
     qmlRegisterUncreatableType<AppView>(uri, 1, 1, "AppView", "Cannot be created AppView");
     qmlRegisterUncreatableType<TabViewInfo>(uri, 1, 3, "TabViewInfo", "Cannot be created TabView");
 
     qmlRegisterType<SettingSection>(uri, 1, 2, "SettingSection");
-    //     qmlRegisterSingletonInstance<Platform>(uri, 1, 2, "Platform", Platform::instance());
+//     qmlRegisterSingletonInstance<Platform>(uri, 1, 2, "Platform", Platform::instance());
     qmlRegisterSingletonType<Platform>(uri, 1, 2, "Platform", [](QQmlEngine *engine, QJSEngine *scriptEngine) -> QObject * {
         Q_UNUSED(scriptEngine)
         auto platform = Platform::instance();
@@ -172,14 +162,14 @@ void MauiKit::registerTypes(const char *uri)
 #elif defined Q_OS_ANDROID
     qmlRegisterType(componentUrl(QStringLiteral("labs/WindowControlsWindows.qml")), uri, 1, 1, "WindowControls");
 #elif defined Q_OS_LINUX && !defined Q_OS_ANDROID
-    
+
     #if defined Q_PROCESSOR_ARM
-    qmlRegisterType(componentUrl(QStringLiteral("labs/WindowControlsWindows.qml")), uri, 1, 1, "WindowControls");    
+    qmlRegisterType(componentUrl(QStringLiteral("labs/WindowControlsWindows.qml")), uri, 1, 1, "WindowControls");
 #else
     qmlRegisterType(componentUrl(QStringLiteral("labs/CSDControls.qml")), uri, 1, 1, "CSDControls");
     qmlRegisterType(componentUrl(QStringLiteral("labs/WindowControlsLinux.qml")), uri, 1, 1, "WindowControls");
 #endif
-    
+
 #endif
 
     /** PLATFORMS SPECIFIC CONTROLS **/
@@ -198,6 +188,8 @@ void MauiKit::registerTypes(const char *uri)
 
 #elif defined Q_OS_WIN32
     // here window platform integration interfaces
+#elif defined Q_OS_MACOS
+
 #endif
 
     /** DATA MODELING TEMPLATED INTERFACES **/
@@ -206,12 +198,12 @@ void MauiKit::registerTypes(const char *uri)
 
 
     /** MAUI APPLICATION SPECIFIC PROPS **/
-#ifdef COMPONENT_ACCOUNTS
-    qmlRegisterAnonymousType<MauiAccounts>(uri, 1);
-    qmlRegisterType(componentUrl(QStringLiteral("SyncDialog.qml")), uri, 1, 0, "SyncDialog"); // to be rename to accountsDialog
-#endif
-
     /** HELPERS **/
+    qmlRegisterAnonymousType<CSDControls>(uri, 1);
+    qmlRegisterType<CSDButton>(uri, 1, 3, "CSDButton");
+    qmlRegisterType<Notify>(uri, 1, 3, "Notify");
+    qmlRegisterType<NotifyAction>(uri, 1, 3, "NotifyAction");
+
     qmlRegisterUncreatableType<MauiApp>(uri, 1, 0, "App", "Cannot be created App");
     qmlRegisterSingletonType<Handy>(uri, 1, 0, "Handy", [](QQmlEngine *engine, QJSEngine *scriptEngine) -> QObject * {
         Q_UNUSED(engine)
